@@ -28,7 +28,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
-our $VERSION = '0.09_4';
+our $VERSION = '0.10_1';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -79,10 +79,8 @@ sub main {
 			rename link chmod chown truncate utime open read write statfs
 			flush release fsync setxattr getxattr listxattr removexattr);
 	my @subs = map {undef} @names;
-	my @validOpts = qw(ro allow_other default_permissions fsname use_ino nonempty);
 	my $tmp = 0;
 	my %mapping = map { $_ => $tmp++ } @names;
-	my %optmap  = map { $_ => 1 } @validOpts;
 	my @otherargs = qw(debug threaded mountpoint mountopts);
 	my %otherargs = (debug=>0, threaded=>0, mountpoint=>"", mountopts=>"");
 	while(my $name = shift) {
@@ -95,10 +93,6 @@ sub main {
 			$subs[$mapping{$name}] = $subref;
 		}
 	}
-	foreach my $opt ( map {m/^([^=]*)/; $1} split(/,/,$otherargs{mountopts}) ) {
-	  next if exists($optmap{$opt});
-	  croak "Fuse::main: invalid '$opt' argument in mountopts";
-	}
 	if($otherargs{threaded}) {
 		# make sure threads are both available, and loaded.
 		if($Config{useithreads}) {
